==> telephone-sqlserver-3.0.9.jar: telephone/sqls/callanaly/hotlineMonthly.sql <==
--月度工单统计
select
    REPLACE(cdate, 'JANUARY', '') cdate,
	sum(case when workorder_type='抢险' then cvaue else 0 end) qx,
	sum(case when workorder_type='咨询' then cvaue else 0 end) zx,
	sum(case when workorder_type='维修' then cvaue else 0 end) wx,
	sum(case when workorder_type='投诉' then cvaue else 0 end) ts,
	sum(case when workorder_type='停气' then cvaue else 0 end) tq
 from (
select workorder_type,cast(cdate as varchar(100)) cdate,cast(isnull(cvaue,0) as int) cvaue  from (select workorder_type,
sum(case when f_created_date>'{month}-01 00:00:00' and f_created_date<'{month}-01 23:23:59' then 1 else 0 end) january1,
sum(case when f_created_date>'{month}-02 00:00:00' and f_created_date<'{month}-02 23:23:59' then 1 else 0 end) january2,
sum(case when f_created_date>'{month}-03 00:00:00' and f_created_date<'{month}-03 23:23:59' then 1 else 0 end) january3,
sum(case when f_created_date>'{month}-04 00:00:00' and f_created_date<'{month}-04 23:23:59' then 1 else 0 end) january4,
sum(case when f_created_date>'{month}-05 00:00:00' and f_created_date<'{month}-05 23:23:59' then 1 else 0 end) january5,
sum(case when f_created_date>'{month}-06 00:00:00' and f_created_date<'{month}-06 23:23:59' then 1 else 0 end) january6,
sum(case when f_created_date>'{month}-07 00:00:00' and f_created_date<'{month}-07 23:23:59' then 1 else 0 end) january7,
sum(case when f_created_date>'{month}-08 00:00:00' and f_created_date<'{month}-08 23:23:59' then 1 else 0 end) january8,
sum(case when f_created_date>'{month}-09 00:00:00' and f_created_date<'{month}-09 23:23:59' then 1 else 0 end) january9,
sum(case when f_created_date>'{month}-10 00:00:00' and f_created_date<'{month}-10 23:23:59' then 1 else 0 end) january10,
sum(case when f_created_date>'{month}-11 00:00:00' and f_created_date<'{month}-11 23:23:59' then 1 else 0 end) january11,
sum(case when f_created_date>'{month}-12 00:00:00' and f_created_date<'{month}-12 23:23:59' then 1 else 0 end) january12,
sum(case when f_created_date>'{month}-13 00:00:00' and f_created_date<'{month}-13 23:23:59' then 1 else 0 end) january13,
sum(case when f_created_date>'{month}-14 00:00:00' and f_created_date<'{month}-14 23:23:59' then 1 else 0 end) january14,
sum(case when f_created_date>'{month}-15 00:00:00' and f_created_date<'{month}-15 23:23:59' then 1 else 0 end) january15,
sum(case when f_created_date>'{month}-16 00:00:00' and f_created_date<'{month}-16 23:23:59' then 1 else 0 end) january16,
sum(case when f_created_date>'{month}-17 00:00:00' and f_created_date<'{month}-17 23:23:59' then 1 else 0 end) january17,
sum(case when f_created_date>'{month}-18 00:00:00' and f_created_date<'{month}-18 23:23:59' then 1 else 0 end) january18,
sum(case when f_created_date>'{month}-19 00:00:00' and f_created_date<'{month}-19 23:23:59' then 1 else 0 end) january19,
sum(case when f_created_date>'{month}-20 00:00:00' and f_created_date<'{month}-20 23:23:59' then 1 else 0 end) january20,
sum(case when f_created_date>'{month}-21 00:00:00' and f_created_date<'{month}-21 23:23:59' then 1 else 0 end) january21,
sum(case when f_created_date>'{month}-22 00:00:00' and f_created_date<'{month}-22 23:23:59' then 1 else 0 end) january22,
sum(case when f_created_date>'{month}-23 00:00:00' and f_created_date<'{month}-23 23:23:59' then 1 else 0 end) january23,
sum(case when f_created_date>'{month}-24 00:00:00' and f_created_date<'{month}-24 23:23:59' then 1 else 0 end) january24,
sum(case when f_created_date>'{month}-25 00:00:00' and f_created_date<'{month}-25 23:23:59' then 1 else 0 end) january25,
sum(case when f_created_date>'{month}-26 00:00:00' and f_created_date<'{month}-26 23:23:59' then 1 else 0 end) january26,
sum(case when f_created_date>'{month}-27 00:00:00' and f_created_date<'{month}-27 23:23:59' then 1 else 0 end) january27,
sum(case when f_created_date>'{month}-28 00:00:00' and f_created_date<'{month}-28 23:23:59' then 1 else 0 end) january28,
sum(case when f_created_date>'{month}-29 00:00:00' and f_created_date<'{month}-29 23:23:59' then 1 else 0 end) january29,
sum(case when f_created_date>'{month}-30 00:00:00' and f_created_date<'{month}-30 23:23:59' then 1 else 0 end) january30,
sum(case when f_created_date>'{month}-31 00:00:00' and f_created_date<'{month}-31 23:23:59' then 1 else 0 end) january31
from (
			select
				case
					when f_workorder_type='投诉单' or f_workorder_type='咨询单' then f_workorder_type
					when f_workorder_type='报修单' then f_repairtype
				end workorder_type
				,t_serviceworkorder.* from t_serviceworkorder
				where f_state !='撤销' or f_state is null
			) t3
	group by workorder_type
) temp
unpivot( cvaue FOR cdate IN (january1,january2,january3,january4,january5,january6,january7,january8,january9,january10
,january11,january12,january13,january14,january15,january16,january17,january18,january19,january20,january21,january22,january23
,january24,january25,january26,january27,january28,january29,january30,january31)) b
) temp group by cdate
order by cast( REPLACE(cdate,'JANUARY', '') as int)

==> telephone-sqlserver-3.0.19.jar: telephone/sqls/callanaly/hotlineMonthly.sql <==
--月度工单统计
select
    REPLACE(cdate, 'JANUARY', '') cdate,
	sum(case when workorder_type='抢险' then cvaue else 0 end) qx,
	sum(case when workorder_type='咨询' then cvaue else 0 end) zx,
	sum(case when workorder_type='维修' then cvaue else 0 end) wx,
	sum(case when workorder_type='投诉' then cvaue else 0 end) ts,
	sum(case when workorder_type='停气' then cvaue else 0 end) tq
 from (
select workorder_type,cast(cdate as varchar(100)) cdate,cast(isnull(cvaue,0) as int) cvaue  from (select workorder_type,
sum(case when f_created_date>'{month}-01 00:00:00' and f_created_date<'{month}-01 23:23:59' then 1 else 0 end) january1,
sum(case when f_created_date>'{month}-02 00:00:00' and f_created_date<'{month}-02 23:23:59' then 1 else 0 end) january2,
sum(case when f_created_date>'{month}-03 00:00:00' and f_created_date<'{month}-03 23:23:59' then 1 else 0 end) january3,
sum(case when f_created_date>'{month}-04 00:00:00' and f_created_date<'{month}-04 23:23:59' then 1 else 0 end) january4,
sum(case when f_created_date>'{month}-05 00:00:00' and f_created_date<'{month}-05 23:23:59' then 1 else 0 end) january5,
sum(case when f_created_date>'{month}-06 00:00:00' and f_created_date<'{month}-06 23:23:59' then 1 else 0 end) january6,
sum(case when f_created_date>'{month}-07 00:00:00' and f_created_date<'{month}-07 23:23:59' then 1 else 0 end) january7,
sum(case when f_created_date>'{month}-08 00:00:00' and f_created_date<'{month}-08 23:23:59' then 1 else 0 end) january8,
sum(case when f_created_date>'{month}-09 00:00:00' and f_created_date<'{month}-09 23:23:59' then 1 else 0 end) january9,
sum(case when f_created_date>'{month}-10 00:00:00' and f_created_date<'{month}-10 23:23:59' then 1 else 0 end) january10,
sum(case when f_created_date>'{month}-11 00:00:00' and f_created_date<'{month}-11 23:23:59' then 1 else 0 end) january11,
sum(case when f_created_date>'{month}-12 00:00:00' and f_created_date<'{month}-12 23:23:59' then 1 else 0 end) january12,
sum(case when f_created_date>'{month}-13 00:00:00' and f_created_date<'{month}-13 23:23:59' then 1 else 0 end) january13,
sum(case when f_created_date>'{month}-14 00:00:00' and f_created_date<'{month}-14 23:23:59' then 1 else 0 end) january14,
sum(case when f_created_date>'{month}-15 00:00:00' and f_created_date<'{month}-15 23:23:59' then 1 else 0 end) january15,
sum(case when f_created_date>'{month}-16 00:00:00' and f_created_date<'{month}-16 23:23:59' then 1 else 0 end) january16,
sum(case when f_created_date>'{month}-17 00:00:00' and f_created_date<'{month}-17 23:23:59' then 1 else 0 end) january17,
sum(case when f_created_date>'{month}-18 00:00:00' and f_created_date<'{month}-18 23:23:59' then 1 else 0 end) january18,
sum(case when f_created_date>'{month}-19 00:00:00' and f_created_date<'{month}-19 23:23:59' then 1 else 0 end) january19,
sum(case when f_created_date>'{month}-20 00:00:00' and f_created_date<'{month}-20 23:23:59' then 1 else 0 end) january20,
sum(case when f_created_date>'{month}-21 00:00:00' and f_created_date<'{month}-21 23:23:59' then 1 else 0 end) january21,
sum(case when f_created_date>'{month}-22 00:00:00' and f_created_date<'{month}-22 23:23:59' then 1 else 0 end) january22,
sum(case when f_created_date>'{month}-23 00:00:00' and f_created_date<'{month}-23 23:23:59' then 1 else 0 end) january23,
sum(case when f_created_date>'{month}-24 00:00:00' and f_created_date<'{month}-24 23:23:59' then 1 else 0 end) january24,
sum(case when f_created_date>'{month}-25 00:00:00' and f_created_date<'{month}-25 23:23:59' then 1 else 0 end) january25,
sum(case when f_created_date>'{month}-26 00:00:00' and f_created_date<'{month}-26 23:23:59' then 1 else 0 end) january26,
sum(case when f_created_date>'{month}-27 00:00:00' and f_created_date<'{month}-27 23:23:59' then 1 else 0 end) january27,
sum(case when f_created_date>'{month}-28 00:00:00' and f_created_date<'{month}-28 23:23:59' then 1 else 0 end) january28,
sum(case when f_created_date>'{month}-29 00:00:00' and f_created_date<'{month}-29 23:23:59' then 1 else 0 end) january29,
sum(case when f_created_date>'{month}-30 00:00:00' and f_created_date<'{month}-30 23:23:59' then 1 else 0 end) january30,
sum(case when f_created_date>'{month}-31 00:00:00' and f_created_date<'{month}-31 23:23:59' then 1 else 0 end) january31
from (
			select
				case
					when f_workorder_type='投诉单' then '投诉'
					when f_workorder_type='咨询单' then '咨询'
					when f_workorder_type='报修单' then f_repairtype
				end workorder_type
				,t_serviceworkorder.* from t_serviceworkorder
				where f_state !='撤销' or f_state is null
			) t3
	group by workorder_type
) temp
unpivot( cvaue FOR cdate IN (january1,january2,january3,january4,january5,january6,january7,january8,january9,january10
,january11,january12,january13,january14,january15,january16,january17,january18,january19,january20,january21,january22,january23
,january24,january25,january26,january27,january28,january29,january30,january31)) b
) temp group by cdate
order by cast( REPLACE(cdate,'JANUARY', '') as int)
